Documentation
¶
Overview ¶
Package stringslite implements a subset of strings, only using packages that may be imported by "os". It's only meant for use by packages in the standard library. Others should use the strings package instead.
Based on the internal/stringslite package.
Index ¶
- func Clone(a mem.Allocator, s string) string
- func Cut(s, sep string) (string, string)
- func CutPrefix(s, prefix string) (string, bool)
- func CutSuffix(s, suffix string) (string, bool)
- func HasPrefix(s, prefix string) bool
- func HasSuffix(s, suffix string) bool
- func Index(s, substr string) int
- func IndexByte(s string, c byte) int
- func TrimPrefix(s, prefix string) string
- func TrimSuffix(s, suffix string) string
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func TrimPrefix ¶
func TrimSuffix ¶
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.